MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / HessLambdaKernal

Function HessLambdaKernal

XM/include/XM/trustregion.h:43–48  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

41
42template <typename T>
43__global__ void HessLambdaKernal(T* news, T* olds, T* oldsu, size_s n){
44 size_s i = blockIdx.x * blockDim.x + threadIdx.x;
45 if(i<n){
46 news[i] = (3 * olds[i+1] * olds[i+1] - 1) * oldsu[i+1];
47 }
48}
49
50// template <typename T>
51// __global__ void compute_sum(T* v_s, T* s0, double* result, size_s size) {

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected